@echo off
SETLOCAL EnableDelayedExpansion 
CLS

REM *****************************************************************
REM    Configure the SET variables and pathnames locations below to match your setup. 
REM *****************************************************************

REM DaysToKeep = # of daily config backups to keep. 
REM Anything older will be automatically deleted.
SET DaysToKeep=14

REM SageTVDir = your SageTV install directory
SET SageTVDir=C:\Program Files\SageTV

REM backupDir = where you want the backup .zip files for weekly backups stored
SET backupDir=D:\shares\Software\SageTV Backups\Config (daily auto backups)

REM backupTempDir = where you want temp files to be stored before being zipped
SET backupTempDir=D:\SageTV Backup Temp

REM windowsDir = where the irremote.ini file is stored (not everybody has or needs this)
SET windowsDir=C:\WINDOWS

REM zipexeDir = where the zip.exe zipping program is located
SET zipexeDir=D:\shares\Software\SageTV Backups

REM Set numFiles equal to the number of files you have manually defined.
REM Leave it at 0 to have the script ignore the #file definitions.
REM If it's set to 1 it will read the 1file variables and ignore the rest, if it's set
REM to 2 it will read the 1file and 2file variables and ignore the rest, and so on.
REM Set each #filePath line equal to the full pathname of the source file and set
REM each #fileDestination line equal to the directory name that the file will be
REM located in within the backup zip.
REM There are 3 sample file definitions below.  You can add as many
REM additional items as you need, just be sure they are sequentially
REM numbered and the total number is correctly defined by the numFiles.
REM Files defined will be copied from #filePath to #fileDestination.

SET numFiles=0

SET 1filePath=c:\Program Files\SageTV\SageTV\*.frq
SET 1fileDestination=SageTV

SET 2filePath=c:\Program Files\SageTV\webfeedencoder\config\*.*
SET 2fileDestination=webfeedencoder\config

SET 3filePath=c:\etc\etc\etc\testfile7.txt
SET 3fileDestination=Destination Backup Directory

REM Set numDirs equal to the number of directories you have manually defined.
REM Leave it at 0 to have the script ignore the #dir definitions.
REM If it's set to 1 it will read the 1dir variables and ignore the rest, if it's set
REM to 2 it will read the 1file and 2dir variables and ignore the rest, and so on.
REM Set each #dirPath line equal to the full pathname of the source directory and set
REM each #dirDestination line equal to the directory name that the directory will be
REM located in within the backup zip.
REM There are 3 sample directory definitions below.  You can add as many
REM additional items as you need, just be sure they are sequentially
REM numbered and the total number is correctly defined by the numDirs.
REM Directories defined will be xcopied from #dirPath to #dirDestination.
REM Xcopied means the entire source directory structure including files and 
REM subdirectories will be copied.

SET numDirs=0

SET 1dirPath=c:\Program Files\SageTV\webfeedencoder
SET 1dirDestination=webfeedencoder

SET 2dirPath=c:\full\path\to\directory2
SET 2dirDestination=Destination Backup Directory

SET 3dirPath=c:\etc\etc\etc\directory7
SET 3dirDestination=Destination Backup Directory

REM ****************************************************************
REM    End of Configuration.  You shouldn't need to change anything below this point.
REM ****************************************************************

CD "%zipexeDir%"

FOR /F "TOKENS=1* DELIMS= " %%A IN ('DATE/T') DO SET CDATE=%%B
FOR /F "TOKENS=1,2 eol=/ DELIMS=/ " %%A IN ('DATE/T') DO SET mm=%%B
FOR /F "TOKENS=1,2 DELIMS=/ eol=/" %%A IN ('echo %CDATE%') DO SET dd=%%B
FOR /F "TOKENS=2,3 DELIMS=/ " %%A IN ('echo %CDATE%') DO SET yyyy=%%B
FOR /F "TOKENS=1* DELIMS= " %%A IN ('TIME/T') DO SET ampm=%%B
FOR /F "TOKENS=1* DELIMS= " %%A IN ('TIME/T') DO SET CTIME=%%A
FOR /F "TOKENS=1,2 eol=/ DELIMS=: " %%A IN ('TIME/T') DO SET hr=%%A
FOR /F "TOKENS=1,2 DELIMS=: " %%A IN ('echo %CTIME%') DO SET min=%%B
SET date=%mm%-%dd%-%yyyy% %hr%%min%%ampm%
SET folderName=SageTV Config Backup (%date%)

MKDIR "%backupTempDir%\%folderName%"

ECHO Backing up RemoteCodes...
MKDIR "%backupTempDir%\%folderName%\Common\RemoteCodes"
XCOPY "%SageTVDir%\Common\RemoteCodes" "%backupTempDir%\%folderName%\Common\RemoteCodes" /e /q

ECHO Backing up SageTV database and properties...
MKDIR "%backupTempDir%\%folderName%\SageTV"
MKDIR "%backupTempDir%\%folderName%\SageTV\clients"
COPY "%SageTVDir%\SageTV\Wiz.bin" "%backupTempDir%\%folderName%\SageTV"
COPY "%SageTVDir%\SageTV\Wiz.bak" "%backupTempDir%\%folderName%\SageTV"
COPY "%SageTVDir%\SageTV\Sage.properties" "%backupTempDir%\%folderName%\SageTV"
COPY "%SageTVDir%\SageTV\Sage.properties.autobackup" "%backupTempDir%\%folderName%\SageTV"
COPY "%SageTVDir%\SageTV\SageClient.properties" "%backupTempDir%\%folderName%\SageTV"
COPY "%SageTVDir%\SageTV\SageClient.properties.autobackup" "%backupTempDir%\%folderName%\SageTV"
XCOPY "%SageTVDir%\SageTV\clients" "%backupTempDir%\%folderName%\SageTV\clients" /e /q

ECHO Backing up Irremote.ini file...
COPY "%windowsDir%\Irremote.ini" "%backupTempDir%\%folderName%"

IF NOT %numFiles%==0 ECHO Backing up manually defined files... 
FOR /L %%G IN (1,1,%numFiles%) DO (
IF EXIST "!%%GfilePath!" (ECHO ...Backing up !%%GfilePath!
MKDIR "%backupTempDir%\%folderName%\!%%GfileDestination!"
COPY "!%%GfilePath!" "%backupTempDir%\%folderName%\!%%GfileDestination!" ) ELSE (
ECHO ...!%%GfilePath! was not found. Moving on...
))

IF NOT %numDirs%==0 ECHO Backing up manually defined directories...
FOR /L %%G IN (1,1,%numDirs%) DO (
IF EXIST "!%%GdirPath!\*" (ECHO ...Backing up !%%GdirPath!
MKDIR "%backupTempDir%\%folderName%\!%%GdirDestination!"
XCOPY "!%%GdirPath!" "%backupTempDir%\%folderName%\!%%GdirDestination!" /e /q ) ELSE (
ECHO ...!%%GdirPath! was not found. Moving on...
))

ECHO Compressing backup: %folderName%
CD "%backupTempDir%\%folderName%"
"%zipexeDir%\zip.exe" -r -9 -q -S "%backupTempDir%\%folderName%".zip *.*
CD "%zipexeDir%"

ECHO Keeping compressed backup...
COPY "%backupTempDir%\%folderName%.zip" "%backupDir%"
DEL "%backupTempDir%\%folderName%.zip" /q
ECHO Deleting backup directory: %folderName%
RD /s /q "%backupTempDir%\%folderName%"

ECHO Cleaning up old backups...
FORFILES /p "%backupDir%" /m *.zip /d -%DaysToKeep% /c "cmd /c del @path"

ECHO Config backup for %date% complete.